/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.site.teams.uad.anonymizer;

import com.liferay.asset.kernel.model.AssetEntry;
import com.liferay.asset.kernel.service.AssetEntryLocalService;
import com.liferay.portal.kernel.dao.orm.ActionableDynamicQuery;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.model.Team;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.service.TeamLocalService;
import com.liferay.site.teams.uad.constants.SiteTeamsUADConstants;
import com.liferay.user.associated.data.anonymizer.DynamicQueryUADAnonymizer;

import org.osgi.service.component.annotations.Reference;

/**
 * Provides the base implementation for the team UAD anonymizer.
 *
 * <p>
 * This implementation exists only as a container for the default methods
 * generated by ServiceBuilder. All custom service methods should be put in
 * {@link TeamUADAnonymizer}.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @generated
 */
public abstract class BaseTeamUADAnonymizer
	extends DynamicQueryUADAnonymizer<Team> {

	@Override
	public void autoAnonymize(Team team, long userId, User anonymousUser)
		throws PortalException {

		if (team.getUserId() == userId) {
			team.setUserId(anonymousUser.getUserId());
			team.setUserName(anonymousUser.getFullName());

			autoAnonymizeAssetEntry(team, anonymousUser);
		}

		teamLocalService.updateTeam(team);
	}

	@Override
	public void delete(Team team) throws PortalException {
		teamLocalService.deleteTeam(team);
	}

	@Override
	public Class<Team> getTypeClass() {
		return Team.class;
	}

	protected void autoAnonymizeAssetEntry(Team team, User anonymousUser) {
		AssetEntry assetEntry = fetchAssetEntry(team);

		if (assetEntry != null) {
			assetEntry.setUserId(anonymousUser.getUserId());
			assetEntry.setUserName(anonymousUser.getFullName());

			assetEntryLocalService.updateAssetEntry(assetEntry);
		}
	}

	@Override
	protected ActionableDynamicQuery doGetActionableDynamicQuery() {
		return teamLocalService.getActionableDynamicQuery();
	}

	@Override
	protected String[] doGetUserIdFieldNames() {
		return SiteTeamsUADConstants.USER_ID_FIELD_NAMES_TEAM;
	}

	protected AssetEntry fetchAssetEntry(Team team) {
		return assetEntryLocalService.fetchEntry(
			Team.class.getName(), team.getTeamId());
	}

	@Reference
	protected AssetEntryLocalService assetEntryLocalService;

	@Reference
	protected TeamLocalService teamLocalService;

}